diff --git a/xplan-docker/xplan-docker-volume-init/Dockerfile b/xplan-docker/xplan-docker-volume-init/Dockerfile
index 64be6e3aa49f50eb0bb2ea82dd56f3ca3aeb23c3..16fca34566039eea146fb67ec99fde38c9dbb5f7 100644
--- a/xplan-docker/xplan-docker-volume-init/Dockerfile
+++ b/xplan-docker/xplan-docker-volume-init/Dockerfile
@@ -24,7 +24,7 @@ ADD target/xplan-docker-volume-init-*.tgz /xplan-volume-init/
 ADD setupVolumes.sh /xplan-volume-init/
 ADD synthesizer /xplan-volume-init/synthesizer/
 
-COPY src/main/resources/xplan-webservices-inspireplu-workspaces/webapps.properties /xplan-volume-init/xplan-webservices-inspireplu-workspaces/
+COPY src/main/resources/xplan-inspireplu-workspaces/webapps.properties /xplan-volume-init/xplan-inspireplu-workspaces/
 COPY src/main/resources/xplan-validator-workspaces/webapps.properties /xplan-volume-init/xplan-validator-workspaces/
 COPY src/main/resources/xplan-workspaces/webapps.properties /xplan-volume-init/xplan-workspaces/
 
diff --git a/xplan-docker/xplan-docker-volume-init/setupVolumes.sh b/xplan-docker/xplan-docker-volume-init/setupVolumes.sh
index 8bd75748f65e4a959e7b69e183413946d676eb4b..0ddf6725b85c33358732d5178c88b01627732b5f 100755
--- a/xplan-docker/xplan-docker-volume-init/setupVolumes.sh
+++ b/xplan-docker/xplan-docker-volume-init/setupVolumes.sh
@@ -125,26 +125,26 @@ sed -i 's|localhost:5432/xplanbox|'$XPLAN_DB'|g' xplan-workspaces/xplan-manager-
 sed -i 's|name="username" value="xplanbox"|name="username" value="'$XPLAN_DB_USER'"|g' xplan-workspaces/xplan-manager-workspace/jdbc/inspireplucp.xml
 sed -i 's|name="password" value="xplanbox"|name="password" value="'$XPLAN_DB_PASSWORD'"|g' xplan-workspaces/xplan-manager-workspace/jdbc/inspireplucp.xml
 
-sed -i 's|http://localhost:8080/xplan-wms|'$XPLAN_WMS_URL_PUBLIC'/xplan-wms|g' xplan-workspaces/xplansyn-wms-workspace/services/html.gfi
+sed -i 's|http://localhost:8080/xplan-wms|'$XPLAN_WMS_URL_PUBLIC'/xplan-wms|g' xplan-workspaces/xplan-services-wms-workspace/services/html.gfi
 
-sed -i 's|localhost:5432/xplanbox|'$XPLAN_DB'|g' xplan-inspireplu-workspaces/xplan-inspireplu-workspace/jdbc/inspireplu.xml
-sed -i 's|name="username" value="xplanbox"|name="username" value="'$XPLAN_DB_USER'"|g' xplan-inspireplu-workspaces/xplan-inspireplu-workspace/jdbc/inspireplu.xml
-sed -i 's|name="password" value="xplanbox"|name="password" value="'$XPLAN_DB_PASSWORD'"|g' xplan-inspireplu-workspaces/xplan-inspireplu-workspace/jdbc/inspireplu.xml
+sed -i 's|localhost:5432/xplanbox|'$XPLAN_DB'|g' xplan-inspireplu-workspaces/xplan-webservices-inspireplu-workspace/jdbc/inspireplu.xml
+sed -i 's|name="username" value="xplanbox"|name="username" value="'$XPLAN_DB_USER'"|g' xplan-inspireplu-workspaces/xplan-webservices-inspireplu-workspace/jdbc/inspireplu.xml
+sed -i 's|name="password" value="xplanbox"|name="password" value="'$XPLAN_DB_PASSWORD'"|g' xplan-inspireplu-workspaces/xplan-webservices-inspireplu-workspace/jdbc/inspireplu.xml
 
 echo "[$(date -Iseconds)] Configure XPlanServices StorageCRS with srid $XPLAN_SERVICES_DEFAULT_CRS_SRID"
 find xplan-workspaces/xplan-manager-workspace/datasources/feature -iname *.xml -exec sed -i 's|<StorageCRS srid="25832"|<StorageCRS srid="'$XPLAN_SERVICES_DEFAULT_CRS_SRID'"|g' {} \;
-find xplan-workspaces/xplan-wfs-workspace/datasources/feature -iname *.xml -exec sed -i 's|<StorageCRS srid="25832"|<StorageCRS srid="'$XPLAN_SERVICES_DEFAULT_CRS_SRID'"|g' {} \;
-find xplan-workspaces/xplansyn-wms-workspace/datasources/feature -iname *.xml -exec sed -i 's|<StorageCRS srid="25832"|<StorageCRS srid="'$XPLAN_SERVICES_DEFAULT_CRS_SRID'"|g' {} \;
-find xplan-workspaces/xplansyn-wfs-workspace/datasources/feature -iname *.xml -exec sed -i 's|<StorageCRS srid="25832"|<StorageCRS srid="'$XPLAN_SERVICES_DEFAULT_CRS_SRID'"|g' {} \;
+find xplan-workspaces/xplan-services-wfs-workspace/datasources/feature -iname *.xml -exec sed -i 's|<StorageCRS srid="25832"|<StorageCRS srid="'$XPLAN_SERVICES_DEFAULT_CRS_SRID'"|g' {} \;
+find xplan-workspaces/xplan-services-wms-workspace/datasources/feature -iname *.xml -exec sed -i 's|<StorageCRS srid="25832"|<StorageCRS srid="'$XPLAN_SERVICES_DEFAULT_CRS_SRID'"|g' {} \;
+find xplan-workspaces/xplan-services-wfs-syn-workspace/datasources/feature -iname *.xml -exec sed -i 's|<StorageCRS srid="25832"|<StorageCRS srid="'$XPLAN_SERVICES_DEFAULT_CRS_SRID'"|g' {} \;
 find xplan-workspaces/xplan-manager-workspace/datasources/feature -iname *.xml -exec sed -i 's|EPSG:25832</StorageCRS>|'$XPLAN_SERVICES_DEFAULT_CRS'</StorageCRS>|g' {} \;
-find xplan-workspaces/xplan-wfs-workspace/datasources/feature -iname *.xml -exec sed -i 's|EPSG:25832</StorageCRS>|'$XPLAN_SERVICES_DEFAULT_CRS'</StorageCRS>|g' {} \;
-find xplan-workspaces/xplansyn-wms-workspace/datasources/feature -iname *.xml -exec sed -i 's|EPSG:25832</StorageCRS>|'$XPLAN_SERVICES_DEFAULT_CRS'</StorageCRS>|g' {} \;
-find xplan-workspaces/xplansyn-wfs-workspace/datasources/feature -iname *.xml -exec sed -i 's|EPSG:25832</StorageCRS>|'$XPLAN_SERVICES_DEFAULT_CRS'</StorageCRS>|g' {} \;
+find xplan-workspaces/xplan-services-wfs-workspace/datasources/feature -iname *.xml -exec sed -i 's|EPSG:25832</StorageCRS>|'$XPLAN_SERVICES_DEFAULT_CRS'</StorageCRS>|g' {} \;
+find xplan-workspaces/xplan-services-wms-workspace/datasources/feature -iname *.xml -exec sed -i 's|EPSG:25832</StorageCRS>|'$XPLAN_SERVICES_DEFAULT_CRS'</StorageCRS>|g' {} \;
+find xplan-workspaces/xplan-services-wfs-syn-workspace/datasources/feature -iname *.xml -exec sed -i 's|EPSG:25832</StorageCRS>|'$XPLAN_SERVICES_DEFAULT_CRS'</StorageCRS>|g' {} \;
 echo "[$(date -Iseconds)] Configure XPlanWMS CRS"
-find xplan-workspaces/xplansyn-wms-workspace/themes -iname *.xml -exec sed -i 's/<s:CRS>EPSG:25832 EPSG:25833 EPSG:31466 EPSG:31467 EPSG:31468 EPSG:31469 EPSG:4258 EPSG:4326 CRS:84 EPSG:4839<\/s:CRS>/<s:CRS>'"$XPLAN_SERVICES_DEFAULT_CRS $( echo ${XPLAN_SERVICES_QUERY_CRS_ARR[@]} )"'<\/s:CRS>/g' {} \;
-find xplan-workspaces/xplansyn-wms-workspace/themes -iname *raster.xml -exec sed -i 's|<s:CRS>EPSG:25832</s:CRS>|<s:CRS>'$XPLAN_SERVICES_DEFAULT_CRS'</s:CRS>|g' {} \;
+find xplan-workspaces/xplan-services-wms-workspace/themes -iname *.xml -exec sed -i 's/<s:CRS>EPSG:25832 EPSG:25833 EPSG:31466 EPSG:31467 EPSG:31468 EPSG:31469 EPSG:4258 EPSG:4326 CRS:84 EPSG:4839<\/s:CRS>/<s:CRS>'"$XPLAN_SERVICES_DEFAULT_CRS $( echo ${XPLAN_SERVICES_QUERY_CRS_ARR[@]} )"'<\/s:CRS>/g' {} \;
+find xplan-workspaces/xplan-services-wms-workspace/themes -iname *raster.xml -exec sed -i 's|<s:CRS>EPSG:25832</s:CRS>|<s:CRS>'$XPLAN_SERVICES_DEFAULT_CRS'</s:CRS>|g' {} \;
 echo "[$(date -Iseconds)] Configure XPlanWFS QueryCRS"
-find xplan-workspaces/xplan-wfs-workspace/services -iname wfs*.xml -not -iname *_metadata.xml -exec sed -i '/<QueryCRS>EPSG:.*<\/QueryCRS>/d' {} \;
+find xplan-workspaces/xplan-services-wfs-workspace/services -iname wfs*.xml -not -iname *_metadata.xml -exec sed -i '/<QueryCRS>EPSG:.*<\/QueryCRS>/d' {} \;
 
 find xplan-workspaces/xplan*-workspace/services -iname *_metadata.xml -exec sed -i 's|<ProviderName>lat/lon GmbH</ProviderName>|<ProviderName>'"$XPLAN_SERVICES_PROVIDER_NAME"'</ProviderName>|g' {} \;
 find xplan-workspaces/xplan*-workspace/services -iname *_metadata.xml -exec sed -i 's|<ProviderSite>http://www.lat-lon.de</ProviderSite>|<ProviderSite>'"$XPLAN_SERVICES_PROVIDER_SITE"'</ProviderSite>|g' {} \;
@@ -163,19 +163,19 @@ find xplan-workspaces/xplan*-workspace/services -iname *_metadata.xml -exec sed
 
 for crs in "${XPLAN_SERVICES_QUERY_CRS_ARR[@]}"
 do
-  find xplan-workspaces/xplan-wfs-workspace/services -iname wfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>/<QueryCRS>CRS:84<\/QueryCRS><QueryCRS>'$crs'<\/QueryCRS>/g' {} \;
+  find xplan-workspaces/xplan-services-wfs-workspace/services -iname wfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>/<QueryCRS>CRS:84<\/QueryCRS><QueryCRS>'$crs'<\/QueryCRS>/g' {} \;
 done
-find xplan-workspaces/xplan-wfs-workspace/services -iname wfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>/<QueryCRS>CRS:84<\/QueryCRS><QueryCRS>'$XPLAN_SERVICES_DEFAULT_CRS'<\/QueryCRS>/g' {} \;
-find xplan-workspaces/xplan-wfs-workspace/services -iname wfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>//g' {} \;
+find xplan-workspaces/xplan-services-wfs-workspace/services -iname wfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>/<QueryCRS>CRS:84<\/QueryCRS><QueryCRS>'$XPLAN_SERVICES_DEFAULT_CRS'<\/QueryCRS>/g' {} \;
+find xplan-workspaces/xplan-services-wfs-workspace/services -iname wfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>//g' {} \;
 
 echo "[$(date -Iseconds)] Configure XPlanSynWFS QueryCRS"
-find xplan-workspaces/xplansyn-wfs-workspace/services -iname xplansynwfs*.xml -not -iname *_metadata.xml -exec sed -i '/<QueryCRS>EPSG:.*<\/QueryCRS>/d' {} \;
+find xplan-workspaces/xplan-services-wfs-syn-workspace/services -iname xplansynwfs*.xml -not -iname *_metadata.xml -exec sed -i '/<QueryCRS>EPSG:.*<\/QueryCRS>/d' {} \;
 for crs in "${XPLAN_SERVICES_QUERY_CRS_ARR[@]}"
 do
-  find xplan-workspaces/xplansyn-wfs-workspace/services -iname xplansynwfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>/<QueryCRS>CRS:84<\/QueryCRS><QueryCRS>'$crs'<\/QueryCRS>/g' {} \;
+  find xplan-workspaces/xplan-services-wfs-syn-workspace/services -iname xplansynwfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>/<QueryCRS>CRS:84<\/QueryCRS><QueryCRS>'$crs'<\/QueryCRS>/g' {} \;
 done
-find xplan-workspaces/xplansyn-wfs-workspace/services -iname xplansynwfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>/<QueryCRS>CRS:84<\/QueryCRS><QueryCRS>'$XPLAN_SERVICES_DEFAULT_CRS'<\/QueryCRS>/g' {} \;
-find xplan-workspaces/xplansyn-wfs-workspace/services -iname xplansynwfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>//g' {} \;
+find xplan-workspaces/xplan-services-wfs-syn-workspace/services -iname xplansynwfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>/<QueryCRS>CRS:84<\/QueryCRS><QueryCRS>'$XPLAN_SERVICES_DEFAULT_CRS'<\/QueryCRS>/g' {} \;
+find xplan-workspaces/xplan-services-wfs-syn-workspace/services -iname xplansynwfs*.xml -not -iname *_metadata.xml -exec sed -i 's/<QueryCRS>CRS:84<\/QueryCRS>//g' {} \;
 
 echo $XPLAN_SERVICES_API_KEY >> xplan-workspaces/config.apikey
 
@@ -185,30 +185,30 @@ if [ $XPLAN_INIT_RASTERTYPE = "gdal" ]
 then
   echo "[$(date -Iseconds)] Configure rastertype gdal"
   sed -i 's/rasterConfigurationType=geotiff/rasterConfigurationType=gdal/g' xplan-manager-config/managerConfiguration.properties
-  mv xplan-workspaces/xplansyn-wms-workspace/gdal.ignore xplan-workspaces/xplansyn-wms-workspace/gdal.xml
-  mv xplan-workspaces/xplansyn-wms-workspace/datasources/tile/dummy.ignore xplan-workspaces/xplansyn-wms-workspace/datasources/tile/dummy.xml
-  mv xplan-workspaces/xplansyn-wms-workspace/datasources/tile/tilematrixset/dummy.ignore xplan-workspaces/xplansyn-wms-workspace/datasources/tile/tilematrixset/dummy.xml
-  mv xplan-workspaces/xplansyn-wms-workspace/layers/dummyrasterlayer.ignore xplan-workspaces/xplansyn-wms-workspace/layers/dummyrasterlayer.xml
-  find xplan-workspaces/xplansyn-wms-workspace/themes -iname *raster.xml -exec sed -i 's/<!--<LayerStoreId>dummyrasterlayer/<LayerStoreId>dummyrasterlayer/g' {} \;
-  find xplan-workspaces/xplansyn-wms-workspace/themes -iname *raster.xml -exec sed -i 's/dummyrasterlayer<\/LayerStoreId>-->/dummyrasterlayer<\/LayerStoreId>/g' {} \;
+  mv xplan-workspaces/xplan-services-wms-workspace/gdal.ignore xplan-workspaces/xplan-services-wms-workspace/gdal.xml
+  mv xplan-workspaces/xplan-services-wms-workspace/datasources/tile/dummy.ignore xplan-workspaces/xplan-services-wms-workspace/datasources/tile/dummy.xml
+  mv xplan-workspaces/xplan-services-wms-workspace/datasources/tile/tilematrixset/dummy.ignore xplan-workspaces/xplan-services-wms-workspace/datasources/tile/tilematrixset/dummy.xml
+  mv xplan-workspaces/xplan-services-wms-workspace/layers/dummyrasterlayer.ignore xplan-workspaces/xplan-services-wms-workspace/layers/dummyrasterlayer.xml
+  find xplan-workspaces/xplan-services-wms-workspace/themes -iname *raster.xml -exec sed -i 's/<!--<LayerStoreId>dummyrasterlayer/<LayerStoreId>dummyrasterlayer/g' {} \;
+  find xplan-workspaces/xplan-services-wms-workspace/themes -iname *raster.xml -exec sed -i 's/dummyrasterlayer<\/LayerStoreId>-->/dummyrasterlayer<\/LayerStoreId>/g' {} \;
 elif [ $XPLAN_INIT_RASTERTYPE = "geotiff" ]
 then
   echo "[$(date -Iseconds)] Configure rastertype geotiff"
-  rm xplan-workspaces/xplansyn-wms-workspace/datasources/tile/dummy.ignore
-  rm xplan-workspaces/xplansyn-wms-workspace/datasources/tile/tilematrixset/dummy.ignore
-  rm xplan-workspaces/xplansyn-wms-workspace/layers/dummyrasterlayer.ignore
+  rm xplan-workspaces/xplan-services-wms-workspace/datasources/tile/dummy.ignore
+  rm xplan-workspaces/xplan-services-wms-workspace/datasources/tile/tilematrixset/dummy.ignore
+  rm xplan-workspaces/xplan-services-wms-workspace/layers/dummyrasterlayer.ignore
 else
   echo "[$(date -Iseconds)] Configure rastertype mapserver"
   sed -i 's/rasterConfigurationType=geotiff/rasterConfigurationType=mapserver/g' xplan-manager-config/managerConfiguration.properties
-  mv xplan-workspaces/xplansyn-wms-workspace/layers/mapserver.ignore xplan-workspaces/xplansyn-wms-workspace/layers/mapserver.xml
-  mv xplan-workspaces/xplansyn-wms-workspace/datasources/remoteows/mapserver.ignore xplan-workspaces/xplansyn-wms-workspace/datasources/remoteows/mapserver.xml
-  find xplan-workspaces/xplansyn-wms-workspace/themes -iname *raster.xml -exec sed -i 's/<!--<LayerStoreId>mapserver/<LayerStoreId>mapserver/g' {} \;
-  find xplan-workspaces/xplansyn-wms-workspace/themes -iname *raster.xml -exec sed -i 's/mapserver<\/LayerStoreId>-->/mapserver<\/LayerStoreId>/g' {} \;
-  find xplan-workspaces/xplansyn-wms-workspace/themes -iname *raster.xml -exec sed -i 's/<!--<Layer layerStore="mapserver"/<Layer layerStore="mapserver"/g' {} \;
-  find xplan-workspaces/xplansyn-wms-workspace/themes -iname *raster.xml -exec sed -i 's/planrasterarchive<\/Layer>-->/planrasterarchive<\/Layer>/g' {} \;
-  find xplan-workspaces/xplansyn-wms-workspace/themes -iname *raster.xml -exec sed -i 's/planrasterpre<\/Layer>-->/planrasterpre<\/Layer>/g' {} \;
-  find xplan-workspaces/xplansyn-wms-workspace/themes -iname *raster.xml -exec sed -i 's/planraster<\/Layer>-->/planraster<\/Layer>/g' {} \;
-  sed -i 's|http://localhost:8080/mapserver|'$XPLAN_MAPSERVER_URL_INTERNAL'/mapserver|g' xplan-workspaces/xplansyn-wms-workspace/datasources/remoteows/mapserver.xml
+  mv xplan-workspaces/xplan-services-wms-workspace/layers/mapserver.ignore xplan-workspaces/xplan-services-wms-workspace/layers/mapserver.xml
+  mv xplan-workspaces/xplan-services-wms-workspace/datasources/remoteows/mapserver.ignore xplan-workspaces/xplan-services-wms-workspace/datasources/remoteows/mapserver.xml
+  find xplan-workspaces/xplan-services-wms-workspace/themes -iname *raster.xml -exec sed -i 's/<!--<LayerStoreId>mapserver/<LayerStoreId>mapserver/g' {} \;
+  find xplan-workspaces/xplan-services-wms-workspace/themes -iname *raster.xml -exec sed -i 's/mapserver<\/LayerStoreId>-->/mapserver<\/LayerStoreId>/g' {} \;
+  find xplan-workspaces/xplan-services-wms-workspace/themes -iname *raster.xml -exec sed -i 's/<!--<Layer layerStore="mapserver"/<Layer layerStore="mapserver"/g' {} \;
+  find xplan-workspaces/xplan-services-wms-workspace/themes -iname *raster.xml -exec sed -i 's/planrasterarchive<\/Layer>-->/planrasterarchive<\/Layer>/g' {} \;
+  find xplan-workspaces/xplan-services-wms-workspace/themes -iname *raster.xml -exec sed -i 's/planrasterpre<\/Layer>-->/planrasterpre<\/Layer>/g' {} \;
+  find xplan-workspaces/xplan-services-wms-workspace/themes -iname *raster.xml -exec sed -i 's/planraster<\/Layer>-->/planraster<\/Layer>/g' {} \;
+  sed -i 's|http://localhost:8080/mapserver|'$XPLAN_MAPSERVER_URL_INTERNAL'/mapserver|g' xplan-workspaces/xplan-services-wms-workspace/datasources/remoteows/mapserver.xml
 fi
 
 sed -i 's|validatorWmsEndpoint=|validatorWmsEndpoint='$XPLAN_VALIDATORWMS_URL_PUBLIC'\/xplan-validator-wms\/services\/wms|g' xplan-validator-config/validatorConfiguration.properties
diff --git a/xplan-docker/xplan-docker-volume-init/src/assembly/xplan-docker-volumes.xml b/xplan-docker/xplan-docker-volume-init/src/assembly/xplan-docker-volumes.xml
index 072a7ac8b5cad5902517d28e096e046eb3ad5fb0..b8f532926018863fd719448e2c77915ff7a66a00 100644
--- a/xplan-docker/xplan-docker-volume-init/src/assembly/xplan-docker-volumes.xml
+++ b/xplan-docker/xplan-docker-volume-init/src/assembly/xplan-docker-volumes.xml
@@ -18,9 +18,9 @@
       <useProjectArtifact>false</useProjectArtifact>
     </dependencySet>
     <dependencySet>
-      <outputDirectory>/xplan-workspaces/xplan-services-wfs-wfs-workspace</outputDirectory>
+      <outputDirectory>/xplan-workspaces/xplan-services-wfs-syn-workspace</outputDirectory>
       <includes>
-        <include>${project.groupId}:xplan-webservices-workspaces::xplan-wfs-services-workspace</include>
+        <include>${project.groupId}:xplan-webservices-workspaces::xplan-services-wfs-syn-workspace</include>
       </includes>
       <unpack>true</unpack>
       <useProjectArtifact>false</useProjectArtifact>
@@ -85,7 +85,7 @@
       <unpack>true</unpack>
       <useProjectArtifact>false</useProjectArtifact>
     </dependencySet>
-    <!--xplan-webservices-inspireplu-workspaces-->
+    <!--xplan-inspireplu-workspaces-->
     <dependencySet>
       <outputDirectory>/xplan-inspireplu-workspaces/xplan-webservices-inspireplu-workspace</outputDirectory>
       <includes>
@@ -121,8 +121,8 @@
     </fileSet>
     <!--xplan-inspireplu-workspaces-->
     <fileSet>
-      <outputDirectory>xplan-webservices-inspireplu-workspaces</outputDirectory>
-      <directory>src/main/resources/xplan-webservices-inspireplu-workspaces</directory>
+      <outputDirectory>xplan-inspireplu-workspaces</outputDirectory>
+      <directory>src/main/resources/xplan-inspireplu-workspaces</directory>
     </fileSet>
     <!--xplan-validator-workspaces-->
     <fileSet>
diff --git a/xplan-docker/xplan-docker-volume-init/src/main/resources/xplan-webservices-inspireplu-workspaces/webapps.properties b/xplan-docker/xplan-docker-volume-init/src/main/resources/xplan-inspireplu-workspaces/webapps.properties
similarity index 100%
rename from xplan-docker/xplan-docker-volume-init/src/main/resources/xplan-webservices-inspireplu-workspaces/webapps.properties
rename to xplan-docker/xplan-docker-volume-init/src/main/resources/xplan-inspireplu-workspaces/webapps.properties
diff --git a/xplan-docker/xplan-docker-volume-init/src/main/resources/xplan-workspaces/webapps.properties b/xplan-docker/xplan-docker-volume-init/src/main/resources/xplan-workspaces/webapps.properties
index 4ad62458e02f374dd42933c9353c7090166affa0..49d7567bc9c78efccb01b2380f70c08646a4d2a6 100644
--- a/xplan-docker/xplan-docker-volume-init/src/main/resources/xplan-workspaces/webapps.properties
+++ b/xplan-docker/xplan-docker-volume-init/src/main/resources/xplan-workspaces/webapps.properties
@@ -18,6 +18,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # #L%
 ###
-/xplan-wms=xplansyn-wms-workspace
-/xplansyn-wfs=xplansyn-wfs-workspace
-/xplan-wfs=xplan-wfs-workspace
+/xplan-wms=xplan-services-wms-workspace
+/xplansyn-wfs=xplan-services-wfs-syn-workspace
+/xplan-wfs=xplan-services-wfs-workspace
diff --git a/xplan-tests/xplan-tests-manual/src/main/resources/xPlanBox-testplan.md b/xplan-tests/xplan-tests-manual/src/main/resources/xPlanBox-testplan.md
index 65d5981191824aadf563b294ab3be8627650763a..2d13d068b074e72b3f64fc904be0247e7c16dd97 100644
--- a/xplan-tests/xplan-tests-manual/src/main/resources/xPlanBox-testplan.md
+++ b/xplan-tests/xplan-tests-manual/src/main/resources/xPlanBox-testplan.md
@@ -700,7 +700,7 @@ Schritt | Beschreibung | Erwartetes Ergebnis
 **Hinweis**
 
 * [1]  `./sortDateUpdate`
-* [2]  `.deegree/xplansyn-wms-workspace/themes/bplanraster.xml`
+* [2]  `.deegree/xplan-wms-syn-workspace/themes/bplanraster.xml`
   * Der Pfad kann variieren.
 
 # 7. XPlanTransformCLI  
diff --git a/xplan-webservices/xplan-webservices-services/xplan-services-wms/src/main/webapp/WEB-INF/web.xml b/xplan-webservices/xplan-webservices-services/xplan-services-wms/src/main/webapp/WEB-INF/web.xml
index 7ae3b9655b41f64b432e6cc8eb812ad0c7918dfe..14a1aa55d9d1bff671cb5faa756eec5600456978 100644
--- a/xplan-webservices/xplan-webservices-services/xplan-services-wms/src/main/webapp/WEB-INF/web.xml
+++ b/xplan-webservices/xplan-webservices-services/xplan-services-wms/src/main/webapp/WEB-INF/web.xml
@@ -143,7 +143,7 @@
     <servlet-class>de.latlon.xplan.wms.GetAttachmentHandler</servlet-class>
     <init-param>
       <param-name>workspaceName</param-name>
-      <param-value>xplansyn-wms-workspace</param-value>
+      <param-value>xplan-wms-syn-workspace</param-value>
     </init-param>
     <init-param>
       <param-name>jdbcConnectionId</param-name>
diff --git a/xplan-core/xplan-core-manager/src/main/java/de/latlon/xplan/manager/workspace/WorkspaceUtils.java b/xplan-core/xplan-core-manager/src/main/java/de/latlon/xplan/manager/workspace/WorkspaceUtils.java
index b8e8f98c7121a368fe14485680fb98f7cae5e0a0..7ad58c946980d0220ea78eb285d04688e3319784 100644
--- a/xplan-core/xplan-core-manager/src/main/java/de/latlon/xplan/manager/workspace/WorkspaceUtils.java
+++ b/xplan-core/xplan-core-manager/src/main/java/de/latlon/xplan/manager/workspace/WorkspaceUtils.java
@@ -40,7 +40,7 @@ public class WorkspaceUtils {
 
 	private static final Logger LOG = LoggerFactory.getLogger(WorkspaceUtils.class);
 
-	public static final String DEFAULT_XPLANSYN_WMS_WORKSPACE = "xplansyn-wms-workspace";
+	public static final String DEFAULT_XPLANSYN_WMS_WORKSPACE = "xplan-wms-syn-workspace";
 
 	public static final String DEFAULT_XPLAN_MANAGER_WORKSPACE = "xplan-manager-workspace";
 
@@ -106,7 +106,7 @@ public class WorkspaceUtils {
 	/**
 	 * @param workspaceDir directory to use as workspace, may be <code>null</code>
 	 * @return the location of the workspace (passed directory or the workspace with
 	 * default name ('xplansyn-wms-workspace') in the deegree workspace root directory) if
 	 * exist, never <code>null</code>
 	 * @throws Exception - if a workspace with the given name does not exist
 	 */
@@ -106,7 +106,7 @@ public class WorkspaceUtils {
 	 * @param workspaceDir directory to use as workspace, may be <code>null</code>
 	 * @return the location of the workspace (passed directory or the workspace with
-	 * default name ('xplansyn-wms-workspace') in the deegree workspace root directory) if
+	 * default name ('xplan-wms-syn-workspace') in the deegree workspace root directory) if
 	 * exist, never <code>null</code>
 	 * @throws Exception - if a workspace with the given name does not exist